@@ -42,108 +42,105 @@ class Processor:
 
     def sanity_checks(self):
         if not self.input or not self.input_exists:
-            return (False, f"The input specified '{self.input}' did not exist. Input must be an existing directory or file.")
+            return (False, f"The input specified '{self.input}' did not exist. Input must be an existing directory or file")
         if not self.overwrite and self.on_change:
-            return (False, f"On-change will not have an effect so long as overwrite is not enabled.")
+            return (False, f"On-change will not have an effect so long as overwrite is not enabled")
         if not self.output and not self.overwrite and not self.format:
-            return (False, f"Only input '{self.input}' was specified. Without a setting for 'output', 'overwrite' and/or 'format' all processing will fail.")
+            return (False, f"Only input '{self.input}' was specified. Without a setting for 'output', 'overwrite' and/or 'format' all processing will fail")
         if path_is_in_path(self.input, self.output):
-            return (False, f"The output '{self.output}' is a subpath of input '{self.input}'.")
+            return (False, f"The output '{self.output}' is a subpath of input '{self.input}'")
         if path_is_in_path(self.output, self.input):
-            return (False, f"The input '{self.input}' is a subpath of output '{self.output}'.")
+            return (False, f"The input '{self.input}' is a subpath of output '{self.output}'")
         return True, None
 
     def process_file(self, input_path: str, output_path: str):
         if self.verbose:
             logger.info(f"Processing '{input_path}' to '{output_path}'")
         if not input_path:
-            logger.warning("No input path specified")
-            return False
+            return False, False, False, "No input path specified"
         if not output_path:
-            logger.warning("No output path specified")
-            return False
-        input_mtime = now
+            return False, False, False, "No output path specified"
+        input_mtime = now.timestamp()
         if os.path.isfile(output_path):
             if not self.overwrite:
-                logger.warning(f"Trying to overwrite '{output_path}' without overwrite enabled")
-                return False
+                return False, False, False, "Trying to overwrite without overwrite enabled"
             if self.on_change:
                 input_mtime = os.path.getmtime(input_path)
                 output_mtime = os.path.getmtime(output_path)
                 if input_mtime == output_mtime:
-                    if self.verbose:
-                        logger.info("File '{output_path}' not changed, skipping")
-                    return True
+                    return True, False, True, f"File not changed ({input_mtime}), skipping"
                 elif output_mtime > input_mtime:
-                    logger.warning(f"Destination file '{output_path}' newer than input, skipping")
-                    return True
+                    return True, False, True, f"Destination file newer than input ({output_mtime}>{input_mtime}), skipping"
         else:
             output_dir = os.path.dirname(output_path)
             if not os.path.isdir(output_dir):
                 os.makedirs(name=output_dir, exist_ok=True)
             if not os.path.isdir(output_dir):
-                logger.warning(f"Directory of '{output_path}' did not exist or could not be created.")
-                return False
+                return False, False, False, "Output directory did not exist or could not be created"
         extension = determine_file_extension(input_path)
         if not extension:
-            logger.warning(f"Unknown extension '{extension}' for input file: '{input_path}'.")
-            return False
+            return False, False, False, f"Unknown extension '{extension}' for input file"
         processor, is_binary = self.processor_map.get(extension, None)
         if not processor:
-            logger.warning(f"Could not find processor for input file '{input_path}'.")
-            return False
+            return False, False, False, "Could not find processor for input file"
         original_content = None
         try:
             with open(input_path, "rb") if is_binary else open(input_path, "r", encoding="utf-8") as file:
                 original_content = file.read()
         except Exception as err:
-            logger.warning(f"Could not load data from input file '{input_path}': {err}.")
-            return False
-        if None == original_content:
-            logger.warning(f"Input file '{input_path}' was empty.")
-            # return False # This is only a warning and not an error
+            return False, False, False, f"Could not load data from input file: {err}"
+        if not original_content:
+            logger.warning(f"Input file '{input_path}' was empty")
         processed_content = None
+        was_copied = False
         if extension in ["js", "css", "html", "svg", "png", "jpeg"] and self.settings.get(f"disable_{extension}", False):
             # Perform copy
             # logger.info(f"SUPPOSED TO COPY: {input_path} ({extension})")
             processed_content = original_content
+            was_copied = True
         else:
             # logger.info(f"SUPPOSED TO PROCESS: {input_path} ({extension})")
             processed_content = processor(original_content, self.settings)
+            # TODO: make message mechanism for processor
         # logger.info(f"Content of file {input_path} was of type {type(original_content)} while processed {type(processed_content)}")
         if None == processed_content:
-            logger.warning(f"Processed file for '{input_path}' was empty.")
-            # return False # This is only a warning and not an error
+            logger.warning(f"Processed file for '{input_path}' was empty")
         try:
             with open(output_path, "wb") if is_binary else open(output_path, "w", encoding="utf-8") as file:
                 written = file.write(processed_content)
                 if written != len(processed_content):
-                    logger.warning(f"Partially written output ({written} of {len(processed_content)} bytes).")
-                    return False
+                    return False, False, False, f"Partially written output ({written} of {len(processed_content)} bytes)"
         except Exception as err:
-            logger.warning(f"Could not write data to output file '{output_path}': {err}.")
-            return False
+            return False, False, False, f"Could not write data to output file: {err}"
         try:
-            input_mtime_mod = time.mktime(input_mtime.timetuple())
-            os.utime(output_path, (input_mtime_mod, input_mtime_mod))
+            os.utime(output_path, (input_mtime, input_mtime))
         except Exception as err:
-            logger.warning(f"Could not correct modify date of output file '{output_path}': {err}.")
-            return False
+            return False, False, False, f"Could not modify date of output file: {err}"
         # All went well, go home happy!
-        return True
+        return True, was_copied, False, None
 
     def process_files_list(self, list):
         start_time = datetime.datetime.now()
         success_count = 0
+        copied_count = 0
+        skipped_count = 0
+        messages = {}
         # logger.info(f'Spreading workload over {multiprocessing.cpu_count()} CPU cores')
         # self.pool = multiprocessing.Pool(multiprocessing.cpu_count())
         for item in list:
             input_path = item["input_path"]
             output_path = item["output_path"]
             single_start_time = datetime.datetime.now()
-            success = self.process_file(input_path=input_path, output_path=output_path)
+            success, copied, skipped, message = self.process_file(input_path=input_path, output_path=output_path)
             if success:
                 success_count += 1
+            if copied:
+                copied_count += 1
+            if skipped:
+                skipped_count += 1
+            if message:
+                messages[message] = 1 + messages.get(message, 0)
+
             single_end_time = datetime.datetime.now()
             single_interval = single_end_time - single_start_time
             if single_interval > datetime.timedelta(seconds=1):
@@ -153,7 +150,12 @@ class Processor:
         # self.pool=None
         end_time = datetime.datetime.now()
         interval = end_time - start_time
-        logger.info(f"Successful processing of {success_count}/{len(list)} items took {human_delta(interval)} total")
+        failed = len(list) - success_count
+        logger.info(f"Processing of {len(list)} files with {success_count} successful, {copied_count} copied and {skipped_count} skipped, generated {len(messages)} message(s) and took {human_delta(interval)} total")
+        if messages:
+            logger.warning(f"Messages encountered were:")
+            for message, count in messages.items():
+                logger.warning(f"{count} x {message}")
         return True
 
     def _process_existing_dir_to_existing_dir(self):
